/* admin-script.js */

jQuery(document).ready(function($) {
	$('.codeBlock').click(function() {
        // Select the text inside the code block
        var codeText = $(this).text();
        
        // Create a temporary textarea to hold the text
        var tempTextarea = $('<textarea>').val(codeText).appendTo('body').select();
        
        // Execute the copy command
        document.execCommand('copy');
        
        // Remove the temporary textarea
        tempTextarea.remove();
        
        // Show alert message
        alert('Code copied!');
    });


   function scrollToTop(){
        $('html, body').animate({
            scrollTop: 0
        }, 1000);
    }
	
	function scrollToBottom(){
        $('html, body').animate({
            scrollTop: $(document).height() - $(window).height()
        }, 1000);
    }


    $('.quickaffilink-tabs ul li:first-child a').addClass('active');
    $('.quickaffilink-tabs div:first-child').addClass('active');

    $('.quickaffilink-tabs ul li a').click(function(event) {
        event.preventDefault();
        var tab_id = $(this).attr('href');

        $('.quickaffilink-tabs ul li a').removeClass('active');
        $('.quickaffilink-tabs div').removeClass('active');

        $(this).addClass('active');
        $(tab_id).addClass('active');
    });

    $('#fetch-product-btn,#refetch-product-btn').on('click', function() {
        var store_url = $('#store_url').val();
        var productUrl = $('#product-url').val();
       
        // Extract domain from product URL
        var domainRegex = /^(?:https?:\/\/)?(?:[^@\n]+@)?(?:www\.)?([^:\/\n?]+)/;
        var match = productUrl.match(domainRegex);
        if (match && match.length > 1) {
            var productDomain = match[1];

            // Compare store domain with product domain
            if (productDomain !== store_url) {
                // Domain doesn't match, prevent further action
                alert('Product URL domain does not match selected store domain.');
                return;
            }
        } else {
            // Invalid URL format
            alert('Invalid product URL format.');
            return;
        }
		$('#ldr').show();
        // Perform AJAX request to fetch product data
        $.ajax({
            url: ajaxurl, // WordPress AJAX handler URL
            type: 'POST',
            data: {
                action: 'quickaffilink_fetch_product_data',
                store_url: store_url,
                product_url: productUrl,
                security: ajax_object.ajax_nonce // Nonce for security
            },
            success: function(response) {
                // Display fetched product data on the screen
                //scrollToBottom();
                $('#save-product-btn').show();
				$('.quickaffilink-form-container').hide();
				$('#product-details').html(response);

            },
			error: function(xhr, status, error) {
				var errorMessage = xhr.status + ': ' + xhr.statusText;
				if (xhr.responseText) {
					errorMessage += '\n' + xhr.responseText;
				}
				alert('Failed to fetch product data. Error: ' + errorMessage);
			}

        });
    });

    $('#save-product-btn').on('click', function() {
        // Perform AJAX request to save product data in the database
		if($('#title').val() == ""){
			alert('No Data to save, try fetching again!');
            return;
		}


        $.ajax({
            url: ajaxurl, // WordPress AJAX handler URL
            type: 'POST',
            data: {
                action: 'quickaffilink_save_product_data',
                store_url: $('#store_url').val(),
                product_url: $('#product-url').val(),
				product_overview: $('#product_overview').val(),
                title: $('#title').val(),
				category: $('#category').val(),
				asin: $('#asin').val(),
				rating_score: $('#rating_score').val(),
				num_ratings: $('#num_ratings').val(),
				price: $('#price').val(),
				currency: $('#currency').val(),
				brand: $('#brand').val(),
				saving: $('#saving').val(),
				stock: $('#stock').val(),
				image_url: $('#image_url').val(),
				hi_res_images_1: $('#hi-res-images_1').val(),
				hi_res_images_2: $('#hi-res-images_2').val(),
				hi_res_images_3: $('#hi-res-images_3').val(),
				hi_res_images_4: $('#hi-res-images_4').val(),
				large_images_1: $('#large-images_1').val(),
				large_images_2: $('#large-images_2').val(),
				large_images_3: $('#large-images_3').val(),
				large_images_4: $('#large-images_4').val(),
				thumb_images_1: $('#thumb-images_1').val(),
				thumb_images_2: $('#thumb-images_2').val(),
				thumb_images_3: $('#thumb-images_3').val(),
				thumb_images_4: $('#thumb-images_4').val(),
                security: ajax_object.ajax_nonce // Nonce for security
            },
            success: function(response) {
                $('#product-details').html(''); // Clear product details
                $('#save-product-btn').hide();
				$('.quickaffilink-form-container').hide();
				$('#fetch-product-btn').hide();
				scrollToTop();
				$('#product-success').html(response);
            },
            error: function() {
                alert('Failed to save product data. Please try again.');
            }
        });
    });

// Define modal variables
var modal = $("#quickaffilink-myModal");
var span = modal.find(".quickaffilink-close");

// When the user clicks on <span> (x), close the modal
span.click(function() {
    hideModal();
});

// Function to show modal with changing messages
function showModalWithMessages(messages) {
    var currentIndex = 0;

    function displayNextMessage() {
        if (currentIndex < messages.length) {
            $('#quickaffilink-modal-message').text(messages[currentIndex]);
            modal.fadeIn();
            currentIndex++;
            // Set a timeout to display the next message after two seconds
            setTimeout(displayNextMessage, 2000);
        } else {
            // All messages displayed, hide the modal
            hideModal();
        }
    }

    // Start displaying messages
    displayNextMessage();
}

// Function to hide modal
function hideModal() {
    modal.fadeOut();
}

// AJAX call function
$('.update-product-btn').on('click', function() {
    var productId = $(this).data('product-id');

	 if (!confirm("Are you sure you want to update and refetch this data from Amazon?")) {
		return;
	 }

    // Show modal with loading messages
    showModalWithMessages([
        'Connecting to Amazon....',
        'Fetching data and checking.....',
        'Updating the records in our system....',
        'Further validation in progress....',
        'Taking more time than expected... hold down...',
        'Completed .. wrapping up... will let you know in case of issues...'
    ]);

    // Send AJAX request
    $.ajax({
        type: 'POST',
        url: ajaxurl, // WordPress AJAX handler URL
        data: {
            action: 'quickaffilink_update_product_info',
            product_id: productId
        },
        success: function(response) {
            hideModal(); // Hide modal
            
            // Log response to console
            console.log(response);

            // Display data from the server
            $('#quickaffilink-modal-message').html(response); // Update modal message with received data

            // Optionally, you can reload the page after updating
            location.reload();
		  },
        error: function(xhr, status, error) {
            hideModal(); // Hide modal
            console.error(xhr.responseText); // Log error message
            alert('An error occurred while updating the product information');
		 }
		});
	});

	 $("#product_sample_form").submit(function(event) {
			if (!$("select[name='product_id']").val()) {
				alert("Please select a product!");
				event.preventDefault(); // Prevent form submission
			}
		});


});
		

function confirmDelete(productId, productName) {
    if (confirm("Are you sure you want to delete '" + productName + "'?")) {
        // Get the form element
        var form = document.getElementById('quickaffilink_del_form');
        
        // Set the value of the hidden product_id field
        form.product_id.value = productId;
        
        // Submit the form
        form.submit();
    }
}


