<?php
// functions.php
if(!defined('ABSPATH')){
	die('Hacking Attempt!');
}
/**
 * Defines an array of Amazon stores with their locations.
 * 
 * @return array An associative array where keys are store locations and values are store URLs.
 */
function quickaffilink__default_options() {
    return array(
        'USA' => 'amazon.com',
        'Canada' => 'amazon.ca',
        'Mexico' => 'amazon.com.mx',
        'Brazil' => 'amazon.com.br',
        'United Kingdom' => 'amazon.co.uk',
        'Germany' => 'amazon.de',
        'France' => 'amazon.fr',
        'Italy' => 'amazon.it',
        'Spain' => 'amazon.es',
        'Netherlands' => 'amazon.nl',
        'Australia' => 'amazon.com.au',
        'India' => 'amazon.in',
        'Singapore' => 'amazon.sg',
        'United Arab Emirates' => 'amazon.ae'
        // Add more stores when needed
    );
}

// Plugin Activation Hook
function quickaffilink_activate_plugin() {
    // Create custom tables
	quickaffilink_create_config_table();
	quickaffilink_create_product_table();
	quickaffilink_create_shortcode_usage_tables();
	
    // Prepopulate the table with default configurations
    quickaffilink_prepopulate_config_table();
}

// Plugin Deactivation Hook
function quickaffilink_deactivate_plugin() {
    // Delete plugin tables
    global $wpdb;
   
   // do not delete products table
	//$table_name = $wpdb->prefix . 'quickaffilink_products';
    //$wpdb->query("DROP TABLE IF EXISTS $table_name");

	$config_table = $wpdb->prefix . 'quickaffilink_config';
    $wpdb->query("DROP TABLE IF EXISTS $config_table");

    $shortcode_usage_table_name = $wpdb->prefix . 'quickaffilink_sc_stats';
    $wpdb->query("DROP TABLE IF EXISTS $shortcode_usage_table_name");

	$clicked_info_table_name = $wpdb->prefix . 'quickaffilink_sc_prod_stats';
    $wpdb->query("DROP TABLE IF EXISTS $clicked_info_table_name");

}


/**
 * Adds Menu Items for QuickAffiLink plugin.
 * Registers menu pages and subpages for the plugin.
 * 
 * @return void
 */

function quickaffilink_add_menu_items() {
    $icon_url = plugins_url( 'assets/images/quickaffilink_icon.png', __FILE__ ); // Generate the URL for the custom image
    // Main Guidelines Page
    add_menu_page( 'QuickAffiLink', 'QuickAffiLink', 'manage_options', 'quickaffilink-main', 'quickaffilink_render_dashboard', $icon_url, 5); // Used $icon_url for the icon
  
    // Submenu Pages
    add_submenu_page( 'quickaffilink-main', 'Dashboard', 'Dashboard', 'manage_options', 'quickaffilink-main', 'quickaffilink_render_dashboard' );
    add_submenu_page( 'quickaffilink-main', 'Add Product', 'Add Product', 'manage_options', 'quickaffilink-add-product', 'quickaffilink_render_add_product_page' );
    add_submenu_page( 'quickaffilink-main', 'List Products', 'List Products', 'manage_options', 'quickaffilink-list-products', 'quickaffilink_render_list_products_page' );
    add_submenu_page( 'quickaffilink-main', 'Configurations', 'Configurations', 'manage_options', 'quickaffilink-configuration', 'quickaffilink_render_settings_page' );
    add_submenu_page( 'quickaffilink-main', 'Sample Usage', 'Sample Usage', 'manage_options', 'quickaffilink-sample-usage', 'quickaffilink_render_sample_usage_page' );
    add_submenu_page( 'quickaffilink-main', 'About QuickAffiLink', 'About QuickAffiLink', 'manage_options', 'quickaffilink-about', 'quickaffilink_render_about_plugin_page' );
}

/**
 * Adds a settings link to the action links for the QuickAffilink plugin.
 *
 * This function constructs a settings link HTML element and adds it to the array
 * of action links for the QuickAffilink plugin on the plugins page in the WordPress
 * admin area. Clicking on this link will take users to the configuration page of the plugin.
 *
 * @param array $links An array of existing action links for the plugin.
 * @return array The modified array of action links with the new settings link added.
 */
function quickaffilink_add_settings_link( $links ) {
    // Define your settings page URL
    $settings_link = admin_url( 'admin.php?page=quickaffilink-about#getting_started' );

    // Construct the link HTML
    $settings_link_html = '<a href="' . esc_url( $settings_link ) . '">Getting Started</a>';

    // Add the settings link to the end of the links array
    $links[] = $settings_link_html;

    return $links;
}

// Hook the function to the plugin action links filter hook
add_filter( 'plugin_action_links_quickaffilink/quickaffilink.php', 'quickaffilink_add_settings_link' );

/**
 * Creates the custom table for QuickAffiLink plugin.
 * This table stores product information fetched from affiliate stores.
 * 
 * @return void
 */
function quickaffilink_create_product_table() {
    global $wpdb;

    $table_name = $wpdb->prefix . 'quickaffilink_products';

    $charset_collate = $wpdb->get_charset_collate();

    // Define the SQL query for table creation
	 $sql = "CREATE TABLE $table_name (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
		title varchar(255) NOT NULL,
		category varchar(255),
		asin varchar(50) NULL UNIQUE, 
		brand varchar(255),
		price varchar(10),
		currency varchar(10),
		saving varchar(10),
		rating_score varchar(5),
		num_ratings int,
		stock varchar(100),
		store_url varchar(50),
		image_url varchar(255),
		product_url text,
		product_overview text,
		hi_res_images_1 varchar(255),
		hi_res_images_2 varchar(255),
		hi_res_images_3 varchar(255),
		hi_res_images_4 varchar(255),
		large_images_1 varchar(255),
		large_images_2 varchar(255),
		large_images_3 varchar(255),
		large_images_4 varchar(255),
		thumb_images_1 varchar(255),
		thumb_images_2 varchar(255),
		thumb_images_3 varchar(255),
		thumb_images_4 varchar(255),
		extras varchar(255) DEFAULT Null,
		is_active tinyint(1) DEFAULT 1,
		saved_by bigint(20),
		created_on datetime NOT NULL,
		last_saved datetime,
		PRIMARY KEY  (id),
		INDEX idx_category (category), 
		INDEX idx_last_saved (last_saved)
	) $charset_collate;";


    // Include the WordPress upgrade script for database operations
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    // Execute the SQL query and handle table creation or modification
    dbDelta($sql);
}

/**
 * Creates the configuration table for QuickAffiLink plugin.
 * This table stores configurations for different affiliate stores.
 * 
 * @return void
 */
function quickaffilink_create_config_table() {
    global $wpdb;

    $table_name = $wpdb->prefix . 'quickaffilink_config';
    $charset_collate = $wpdb->get_charset_collate();

    // Define the SQL query for table creation
    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        tld varchar(6) NOT NULL,
        country_name varchar(50) NOT NULL,
        store_url varchar(50) NOT NULL,
        affiliate_tag varchar(150),
        is_default tinyint(1) NOT NULL DEFAULT 0,
        created_by bigint(20) NOT NULL,
		last_updated DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
        creation_date datetime NOT NULL,
        UNIQUE KEY id (id),
        UNIQUE KEY tld_unique (tld),  -- Make 'tld' column unique
        INDEX store_url_index (store_url) 
    ) $charset_collate;";

    // Include the WordPress upgrade script for database operations
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    // Execute the SQL query and handle table creation or modification
    dbDelta($sql);
}

/**
 * Creates the custom tables required for shortcode usage tracking.
 */
function quickaffilink_create_shortcode_usage_tables() {
    global $wpdb;

    // Define table names
    $shortcode_usage_table_name = $wpdb->prefix . 'quickaffilink_sc_stats';
    $clicked_info_table_name = $wpdb->prefix . 'quickaffilink_sc_prod_stats';

    // Define table creation SQL for shortcode usage table
    $shortcode_usage_sql = "CREATE TABLE IF NOT EXISTS $shortcode_usage_table_name (
      id INT AUTO_INCREMENT PRIMARY KEY,
      shortcode_name VARCHAR(50) NOT NULL,
      url VARCHAR(255) NOT NULL,
      displayed_times INT(11) DEFAULT NULL,
      first_detected TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
      last_seen TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
	  INDEX idx_url (url),
	  INDEX idx_shortcode_name (shortcode_name),
	  INDEX idx_last_seen (last_seen)

    )";

    // Define table creation SQL for clicked info table
    $clicked_info_sql = "CREATE TABLE IF NOT EXISTS $clicked_info_table_name (
        id INT AUTO_INCREMENT PRIMARY KEY,
        shortcode_usage_id INT NOT NULL,
		product_id INT NULL DEFAULT 0,
        clicked_at TIMESTAMP NULL DEFAULT NULL,
        INDEX idx_product_id (product_id),
		INDEX idx_clicked_at (clicked_at)
    )";

    // Include the WordPress upgrade script for database operations
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

    // Execute the SQL queries to create tables
    dbDelta($shortcode_usage_sql);
    dbDelta($clicked_info_sql);
}


/**
 * Renders the Add Product Page.
 * Displays a form to add a new product, including selecting the store and entering the product URL.
 * Also includes buttons for fetching product details asynchronously and saving the product.
 * 
 * @global object $wpdb WordPress database access abstraction object.
 * @return void
 */
function quickaffilink_render_add_product_page() {
    global $wpdb;
    $amazon_stores = quickaffilink__default_options();
?>
    <div class="wrap">
        <h1>Add Product</h1>
		<p>This screen alllows you to add the products from amazon store(s) link by link. Go to details page of any product that you want to add copy link, bring it on this screen and paste it with the reference of respective store. <h3>Follow the on-screen instruction until the product is saved and you get a success message.</h3></p>

<div class="quickaffilink-form-container">
<br />
    <form id="quickaffilink-add-product-form">
        <div class="quickaffilink-form-group">
            <label for="store"><?php esc_html_e( 'Select Store:', 'quickaffilink' ); ?></label><br />
            <?php
            // Fetch configurations ordered by is_default
            $configurations = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "quickaffilink_config ORDER BY is_default DESC" );

            // Start generating select element
            echo '<select id="store_url" name="store_url" class="quickaffilink-select">';
            foreach ( $configurations as $config ) {
				$selected = selected( get_option( 'default_affiliate' ), $config->store_url, false );
				echo '<option value="' . esc_attr( $config->store_url ) . '" ' . esc_attr( $selected ) . '>' . esc_html( $config->country_name ) . '</option>';
            }
            echo '</select>';
            ?>
        </div>
        <div class="quickaffilink-form-group">
            <label for="product-url"><?php esc_html_e( 'Product URL:', 'quickaffilink' ); ?></label><br />
			<input type="text" id="product-url" name="product_url" class="quickaffilink-input">
        </div>
        <button type="button" id="fetch-product-btn" class="quickaffilink-btn"><?php esc_html_e( 'Fetch', 'quickaffilink' ); ?></button>
    </form>
</div>


        <div id="product-details">
		<?php $icon_l_url = plugins_url( 'assets/images/loader.gif', __FILE__ ); ?>
			<link rel="preload" as="image" href="<?php echo esc_url( $icon_l_url ); ?>">
			<?php echo '<img src="' . esc_url( $icon_l_url ) . '" id="ldr" width="150" style="display: none;" />'; ?>
        </div>
		
        <button type="button" id="save-product-btn" style="display: none;" class="quickaffilink-btn">Save</button>
		<div id="product-success"></div>
    </div>
<?php
}

// Handle AJAX request to fetch product data
add_action('wp_ajax_quickaffilink_fetch_product_data', 'quickaffilink_fetch_product_data_callback');

// Handle AJAX request to fetch product data
add_action('wp_ajax_quickaffilink_update_product_info', 'quickaffilink_update_product_info_callback');

/**
 * Callback function to update product information.
 */
function quickaffilink_update_product_info_callback() {
    // Retrieve and log the received product ID
   $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
    #error_log('Received product ID: ' . $product_id);

    // Retrieve product_url and store_url from the database based on $product_id
    global $wpdb;
    $table_name = $wpdb->prefix . 'quickaffilink_products';
    $query = $wpdb->prepare("SELECT product_url, store_url FROM $table_name WHERE id = %d", $product_id);
    $result = $wpdb->get_row($query);

    if ($result) {
        // Call get_amazon_data function to fetch data
        $data = quickaffilink_get_amazon_data($result->product_url);

        if ($data) {
            // Prepare data for database update
            $data_to_update = array(
                'title' => $data['title'],
                'category' => $data['category'],
                'asin' => $data['asin'],
                'rating_score' => $data['rating_score'],
                'num_ratings' => $data['num_ratings'],
                'price' => $data['price'],
                'currency' => $data['currency'],
                'brand' => $data['brand'],
                'saving' => $data['saving'],
                'stock' => $data['stock'],
                'store_url' => $result->store_url,
                'product_url' => $result->product_url,
				'product_overview' => $data['product_overview'],
                'image_url' => $data['image_url'],
                'hi_res_images_1' => $data['hi-res-images'][0],
                'hi_res_images_2' => $data['hi-res-images'][1],
                'hi_res_images_3' => $data['hi-res-images'][2],
                'hi_res_images_4' => $data['hi-res-images'][3],
                'large_images_1' => $data['large-images'][0],
                'large_images_2' => $data['large-images'][1],
                'large_images_3' => $data['large-images'][2],
                'large_images_4' => $data['large-images'][3],
                'thumb_images_1' => $data['thumb-images'][0],
                'thumb_images_2' => $data['thumb-images'][1],
                'thumb_images_3' => $data['thumb-images'][2],
                'thumb_images_4' => $data['thumb-images'][3],
                'last_saved' => current_time('mysql') // Update last saved date
            );
            #error_log(' product Overview: ' . $data['product_overview']);
            
			// Update data in the database
            $result = $wpdb->update($table_name, $data_to_update, array('id' => $product_id));

            if ($result !== false) {
                // Output the response data (HTML)
                echo 'Data updated successfully!';
            } else {
                echo 'Error: Could not update data in the database!';
            }
        } else {
            echo 'Error: Could not fetch data from Amazon!';
        }
    } else {
        echo 'Error: Product not found in the database!';
    }

    wp_die(); // Terminate the script after outputting the response
}


/**
 * AJAX callback function to fetch product data asynchronously.
 * Verifies nonce for security, retrieves product URL and store from $_POST,
 * fetches product data using quickaffilink_get_amazon_data(), and dynamically displays
 * product information on the page if data is successfully fetched.
 * 
 * @return void
 */
function quickaffilink_fetch_product_data_callback() {
	// Verify nonce for security
	if (!isset($_POST['security']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['security'])), 'quickaffilink_security_nonce')) {

		wp_die('Nonce verification failed.');
	}

	// Retrieve and sanitize data from $_POST
	$store_url = isset($_POST['store_url']) ? esc_url(sanitize_url(wp_unslash($_POST['store_url']))) : '';
	$product_url = isset($_POST['product_url']) ? esc_url(sanitize_url(wp_unslash($_POST['product_url']))) : '';


    // Perform operations to fetch product data (e.g., using Amazon API)

    $array_res = [];
	$array_res = quickaffilink_get_amazon_data($product_url);

    // Check if product data is successfully fetched
    if($array_res['title'] != ""){

        // Generate HTML markup to display product information
        ?>

        <div class="product-container">
		<a href="<?php echo esc_url( $array_res['url'] ); ?>" class="product-link">
             <img src="<?php echo esc_url( $array_res['image_url'] ); ?>" alt="<?php echo esc_attr( 'Product Image' ); ?>" class="product-main-image">
           
		   
		   
		   
		   
		   
		   
		   <h3 class="product-title"><?php echo esc_html( quickaffilink_trim_title( $array_res['title'], 12 ) ); ?></h3>
            </a>
		<p class="product-price"><?php echo esc_html( $array_res['price'] ); ?> <?php echo esc_html( $array_res['currency'] ); ?></p>
		<p class="product-stock"><?php echo esc_html( $array_res['stock'] ); ?></p>
        </div>
        <?php

        // Generate hidden fields with product data, further proper escaping has been taken care within the function
		echo quickaffilink_generateHiddenFields($array_res); // any other way for echo will affect the logic

    }
    // Return fetched product data
    wp_die();
}

// Handle AJAX request to save product data
add_action('wp_ajax_quickaffilink_save_product_data', 'quickaffilink_save_product_data_callback');

/**
 * Callback function to save product data via AJAX.
 *
 * This function handles AJAX requests to save product data into the database.
 * It verifies the nonce for security, retrieves and sanitizes data from the $_POST array,
 * prepares the data for insertion into the database, and performs the insertion.
 */
function quickaffilink_save_product_data_callback() {
	if (!isset($_POST['security']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['security'])), 'quickaffilink_security_nonce')) {
		wp_die('Nonce verification failed.');
	}
	
	//print_r($_POST);

    // Retrieve and sanitize data from $_POST
    $title = sanitize_text_field(wp_unslash($_POST['title']));
	$category = sanitize_text_field(wp_unslash($_POST['category']));
	$asin = sanitize_text_field(wp_unslash($_POST['asin']));
	$rating_score = sanitize_text_field(wp_unslash($_POST['rating_score']));
	$num_ratings = isset($_POST['num_ratings']) ? intval(wp_unslash($_POST['num_ratings'])) : 0; // Default to 0 if not set
	$price = sanitize_text_field(wp_unslash($_POST['price']));
	$currency = sanitize_text_field(wp_unslash($_POST['currency']));
	$brand = sanitize_text_field(wp_unslash($_POST['brand']));
	$saving = sanitize_text_field(wp_unslash($_POST['saving']));
	$stock = sanitize_text_field(wp_unslash($_POST['stock']));
	$image_url = sanitize_text_field(wp_unslash($_POST['image_url']));   
	$store_url = sanitize_text_field(wp_unslash($_POST['store_url']));
	$product_url = sanitize_text_field(wp_unslash($_POST['product_url']));
	$product_overview = sanitize_text_field(wp_unslash($_POST['product_overview']));

	$hi_res_images_1 = isset($_POST['hi_res_images_1']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['hi_res_images_1']))) : '';
	$hi_res_images_2 = isset($_POST['hi_res_images_2']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['hi_res_images_2']))) : '';
	$hi_res_images_3 = isset($_POST['hi_res_images_3']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['hi_res_images_3']))) : '';
	$hi_res_images_4 = isset($_POST['hi_res_images_4']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['hi_res_images_4']))) : '';

	$large_images_1 = isset($_POST['large_images_1']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['large_images_1']))) : '';
	$large_images_2 = isset($_POST['large_images_2']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['large_images_2']))) : '';
	$large_images_3 = isset($_POST['large_images_3']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['large_images_3']))) : '';
	$large_images_4 = isset($_POST['large_images_4']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['large_images_4']))) : '';

	$thumb_images_1 = isset($_POST['thumb_images_1']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['thumb_images_1']))) : '';
	$thumb_images_2 = isset($_POST['thumb_images_2']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['thumb_images_2']))) : '';
	$thumb_images_3 = isset($_POST['thumb_images_3']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['thumb_images_3']))) : '';
	$thumb_images_4 = isset($_POST['thumb_images_4']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['thumb_images_4']))) : '';


    // Set default currency if not provided
    if ($currency == "") {
        $currency = "$";
    }

    // Get the current user ID
    $saved_by = get_current_user_id();

    // Prepare data for database insertion
    $data = array(
        'title' => $title,
        'category' => $category,
        'asin' => $asin,
        'rating_score' => $rating_score,
        'num_ratings' => $num_ratings,
        'price' => $price,
        'currency' => $currency,
        'brand' => $brand,
        'saving' => $saving,
        'stock' => $stock,
        'store_url' => $store_url,    
        'image_url' => $image_url,
        'product_url' => $product_url,
        'product_overview' => $product_overview,
        'hi_res_images_1' => $hi_res_images_1,
        'hi_res_images_2' => $hi_res_images_2,
        'hi_res_images_3' => $hi_res_images_3,
        'hi_res_images_4' => $hi_res_images_4,
        'large_images_1' => $large_images_1,
        'large_images_2' => $large_images_2,
        'large_images_3' => $large_images_3,
        'large_images_4' => $large_images_4,
        'thumb_images_1' => $thumb_images_1,
        'thumb_images_2' => $thumb_images_2,
        'thumb_images_3' => $thumb_images_3,
        'thumb_images_4' => $thumb_images_4,
        'saved_by' => $saved_by,
        'created_on' => current_time('mysql'),
        'last_saved' => current_time('mysql')
    );

    global $wpdb;

    // Insert data into the database if the title is not empty
    if ($title != "") {
        $table_name = $wpdb->prefix . 'quickaffilink_products';
        $result = $wpdb->insert($table_name, $data);
    }

    // Check if the insert operation was successful
    if (is_null($result) || ($result === false)) {
        // If unsuccessful, display the error message
        echo "Error: Could not add the Product! (Possibly this product already exists)";
		$mysql_error = $wpdb->last_error;
		// Handle the error or log it as needed
		#error_log("MySQL Error: $mysql_error");
    } else {
        // If successful, return success message
        echo '<h2>Product saved successfully!</h2><p> Click here to <a href="admin.php?page=quickaffilink-add-product"><b>Add More Products</b></a> or go to <a href="admin.php?page=quickaffilink-list-products"><b>Products List</b></a> to view added items.</p>';
    }

    // Terminate WordPress execution
    wp_die();
}


// Add nonce to admin_head for use in AJAX requests
/** UPDTED BASED ON REVIEW FEEDBACK add_action('admin_head', 'quickaffilink_add_ajax_nonce'); **/
/**
 * Add AJAX nonce for security.
 *
 * This function adds a JavaScript object containing an AJAX nonce for security purposes.
 * Nonces are used to verify that the authenticated user intended the action.
 */










#############################################################

function quickaffilink_render_settings_page() {
    global $wpdb;

	$table_for_products = $wpdb->prefix . 'quickaffilink_products';  
	$shortcode_usage_table_name = $wpdb->prefix . 'quickaffilink_sc_stats';
	$clicked_info_table_name = $wpdb->prefix . 'quickaffilink_sc_prod_stats';
	$config_table = $wpdb->prefix . 'quickaffilink_config';



	if (isset($_POST['flush_products']) && $_POST['flush_products'] === 'true') {
		// Perform the action to flush all products
		$wpdb->query("TRUNCATE TABLE $table_for_products");
		$wpdb->query("TRUNCATE TABLE $shortcode_usage_table_name");
		$wpdb->query("TRUNCATE TABLE $clicked_info_table_name");
		// Add a success message
		add_settings_error('quickaffilink_messages', 'success', __('All products have been flushed successfully!', 'quickaffilink'), 'updated');
		}

	// Hook the function to handle the form submission
	add_action('admin_init', 'flush_all_products');

	if (isset($_POST['reset-defaults']) && $_POST['reset-defaults'] === 'true') {

		// Perform the action to reset
		global $wpdb;

		$wpdb->query("DROP TABLE IF EXISTS $config_table");
		$wpdb->query("DROP TABLE IF EXISTS $table_for_products");
		$wpdb->query("DROP TABLE IF EXISTS $shortcode_usage_table_name");
		$wpdb->query("DROP TABLE IF EXISTS $clicked_info_table_name");
		
		quickaffilink_create_config_table(); 
		quickaffilink_prepopulate_config_table();
		quickaffilink_create_product_table(); 
		quickaffilink_create_shortcode_usage_tables();
		add_settings_error('quickaffilink_messages', 'success', __('Flush all Data and Reset to Default settings successfully!', 'quickaffilink'), 'updated');
	}

	// Hook the function to handle the form submission
	add_action('admin_init', 'reset_defaults');

    // Check if delete action is triggered
    if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['config_id'])) {
        // Delete configuration
        $config_id = intval($_GET['config_id']);
        $wpdb->delete(
            $wpdb->prefix . 'quickaffilink_config',
            array('id' => $config_id),
            array('%d')
        );

        // Display success message
        add_settings_error('quickaffilink_messages', 'success', __('Configuration deleted successfully.', 'quickaffilink'), 'updated');
    }

    // Check if make default action is triggered
    if (isset($_GET['action']) && $_GET['action'] === 'make_default' && isset($_GET['config_id'])) {
        $config_id = intval($_GET['config_id']);

        // Reset all records' default field to 0
        $wpdb->query("UPDATE {$wpdb->prefix}quickaffilink_config SET is_default = 0 WHERE 1=1");

        // Set the selected configuration as default
        $wpdb->update(
            $wpdb->prefix . 'quickaffilink_config',
            array('is_default' => 1),
            array('id' => $config_id),
            array('%d'),
            array('%d')
        );

        // Display success message
        add_settings_error('quickaffilink_messages', 'success', __('Default store updated successfully.', 'quickaffilink'), 'updated');
    }


	// Check if form is submitted for adding or updating affiliate tag
    if (isset($_POST['quickaffilink_save_affiliate_tag'])) {
        $config_id = isset($_POST['config_id']) ? intval($_POST['config_id']) : 0;
		$affiliate_tag = isset($_POST['affiliate_tag']) ? sanitize_text_field(wp_unslash($_POST['affiliate_tag'])) : '';
		// Update affiliate tag for the configuration
        $wpdb->update(
            $wpdb->prefix . 'quickaffilink_config',
            array('affiliate_tag' => $affiliate_tag),
            array('id' => $config_id),
            array('%s'),
            array('%d')
        );

        // Display success message
        add_settings_error('quickaffilink_messages', 'success', __('Affiliate tag updated successfully.', 'quickaffilink'), 'updated');
    }

    // Fetch configurations
    $configurations = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "quickaffilink_config");

    // Render the settings page
    ?>
    <div class="wrap">
        <h1>Configurations</h1>
        <br />
	<hr />
		<h2>Amazon Store Configurations</h2>
        <?php
        // Display error/success messages
        settings_errors('quickaffilink_messages');
        ?>

        <table class="widefat">
            <thead>
                <tr>
                    <th>Country</th>
                    <th>TLD</th>
                    <th>Store URL</th>
                    <th>Amazon Affiliate Tag</th>
                    <th>Default (Clickable)</th>
                    <th>Action(s)</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($configurations as $config) : ?>
                    <tr>
                        <td><strong><?php echo esc_html($config->country_name); ?></strong></td>
                        <td><?php echo esc_html($config->tld); ?></td>
                        <td><?php echo esc_html($config->store_url); ?></td>
                        <td>
                            <form method="post" action="admin.php?page=quickaffilink-configuration">
								<input type="hidden" name="config_id" value="<?php echo esc_attr( $config->id ); ?>">
                                <input type="text" name="affiliate_tag" value="<?php echo esc_attr($config->affiliate_tag); ?>">
                                <input type="submit" name="quickaffilink_save_affiliate_tag" class="button button-primary" value="Save">
                            </form>
                        </td>
                        <td>
                            <?php if ($config->is_default) : ?>
							<img title="Default Store" src="<?php echo esc_url( plugin_dir_url( __FILE__ ) . 'assets/images/yellow_star.png' ); ?>" alt="<?php echo esc_attr( 'Default' ); ?>" style="width: 20px; height: auto;">
                            <?php else : ?>
								<a title="Click to Make <?php echo esc_attr( esc_html( $config->country_name ) ); ?> store as your Default" href="<?php echo esc_url( '?page=quickaffilink-configuration&action=make_default&config_id=' . $config->id ); ?>"    onclick="return confirm('Do you want to make \'<?php echo esc_js( esc_html( $config->country_name ) ); ?>\' as your default store? \nIt will be pre-selected in the add screen!');">  <img src="<?php echo esc_url( plugin_dir_url( __FILE__ ) . 'assets/images/gray_star.png' ); ?>" alt="<?php echo esc_attr( 'Non-default' ); ?>" style="width: 20px; height: auto;"></a>
                            <?php endif; ?>
                        </td>
                        <td>
						<a style="color:red;" href="<?php echo esc_url( '?page=quickaffilink-configuration&action=delete&config_id=' . $config->id ); ?>" onclick="return confirm('Are you sure you want to delete the store for \'<?php echo esc_js( esc_html( $config->country_name ) ); ?>\'? \nThere is no coming back without re-installing the plugin');">Delete</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    <br />
	<strong>Affiliate Configuration Guidance:</strong> 
		<ol>
		<li>Select the Amazon store that you will be using most frequently and make it your default store. It will come pre-selected on the top in the "Add Product" screen. You can come back and update it again later.</li>
		<li>Update your affiliate tag by adding to the text box and clicking save.</li>
		<li>Make sure for any country for which you are going to get data, you already have an amazon affiliate tag. before adding to the site.</li>
		</ol>
	<hr />
	<div>
	<h2>Flush all products (Delete all products data - Use Wisely)</h2>
	<form method="post" action="admin.php?page=quickaffilink-configuration">
    <input type="hidden" name="flush_products" value="true">
    <button class="button button-primary" type="submit" onclick="return confirm('Are you sure you want to delete all products? \nThere is no coming back.');">Flush All Products</button>
	</form>
	</div>
	<br />
	<hr />
	<div>
	<h2>Flush all Data and Reset to Default Settings</h2>
	<form method="post" action="admin.php?page=quickaffilink-configuration">
	 <input type="hidden" name="reset-defaults" value="true">
    <button class="button button-primary" type="submit" onclick="return confirm('Are you sure you want to reset the plugin to defaults? \nAll data and configurations will be reset.\nThere is no coming back.');">Reset Plugin</button>
	</form>
	</div>
	<br />
	</div>

    <?php
}


/**
 * Render the list products page in the admin dashboard.
 *
 * This function displays a table listing products stored in the database.
 * It includes search functionality, pagination, and an option to delete products.
 */
function quickaffilink_render_list_products_page() {
    global $wpdb;

    $table_name = $wpdb->prefix . 'quickaffilink_products';

    // Number of products per page
    $products_per_page = 10;
    $current_page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
    $offset = ($current_page - 1) * $products_per_page;

    // Search query
	 $search_query = isset($_GET['q']) ? sanitize_text_field(wp_unslash($_GET['q'])) : '';

    // Retrieve products based on search query and pagination
	$sql = $wpdb->prepare("SELECT * FROM $table_name WHERE title LIKE %s OR category LIKE %s ORDER BY id DESC LIMIT %d OFFSET %d", "%{$search_query}%", "%{$search_query}%", $products_per_page, $offset);
    $products = $wpdb->get_results($sql);

    ?>
    <div class="wrap">
        <h1>List Products</h1>
        <br /><br />

        <!-- Search form -->
        <form method="get" action="<?php echo esc_url(admin_url('admin.php')); ?>">
            <input type="hidden" name="page" value="quickaffilink-list-products">
            <input type="text" name="q" value="<?php echo esc_attr($search_query); ?>" placeholder="Search products">
            <input type="submit" value="Search" class="button">
        </form>
		<form id="quickaffilink_del_form" method="post" action="<?php echo admin_url('admin-post.php'); ?>">
		<input type="hidden" name="action" value="delete_product">
		<input type="hidden" name="product_id">
		<?php wp_nonce_field('quickaffilink_delete_product_nonce', 'security'); ?>
		</form>
        <!-- Products table -->
        <table class="wp-list-table widefat striped">
            <thead>
                <tr>
                    <th>Product ID</th>
                    <th>Title</th>
                    <th>Product Image</th>
                    <th>Category</th>
                    <th>Brand</th>
                    <th>ASIN</th>
                    <th>Price</th>
                    <th>Currency</th>
                    <th>Amazon Site</th>
                    <th>Last Updated</th> 
                    <th width="100">Short Code</th>
                    <th>Action</th> 
                </tr>
            </thead>
            <tbody>
                <?php foreach ($products as $product) : ?>
                    <tr>
					<td><?php echo esc_html( $product->id ); ?></td>
						<td><a href="<?php echo esc_url( $product->product_url ); ?>" target="_blank"><?php echo esc_html( $product->title ); ?></a></td>
                        <td><center><a href="<?php echo esc_url($product->product_url); ?>" target="_blank"><img src="<?php echo esc_url($product->image_url); ?>"  style="max-height:100px;max-width:100px;"></a></center></td>
                        <td><?php echo esc_html($product->category); ?></td>
                        <td><?php echo esc_html($product->brand); ?></td>
                        <td><?php echo esc_html($product->asin); ?></td>
                        <td><?php echo esc_html($product->price); ?></td>
                        <td><?php echo esc_html($product->currency); ?></td>
                        <td><?php echo esc_html(quickaffilink_store_country_by_url($product->store_url)); ?></td>
						<td><?php echo esc_html( gmdate( 'Y-m-d H:i:s', strtotime( $product->last_saved ) ) ); ?><br /><br />
						<b><?php echo esc_html( quickaffilink_formatTimeDifference( gmdate( 'Y-m-d H:i:s', strtotime( $product->last_saved ) )) ); ?></b>
						</td> 
						<td>
							<strong><code class="codeBlock">[quickaffilink id="<?php echo esc_attr( $product->id ); ?>"]</code></strong>
							<a href="admin.php?page=quickaffilink-sample-usage">Learn more codes</a>
						</td>
						<td>
							<button onclick="confirmDelete(<?php echo esc_js( $product->id ); ?>, '<?php echo esc_js( esc_html( $product->title ) ); ?>')" style="color:red;">Delete</button><br /><br />
							<button class="update-product-btn" data-product-id="<?php echo esc_attr( $product->id ); ?>">Update</button>
						</td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- Pagination -->
        <?php
        $total_products = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM $table_name WHERE title LIKE %s OR category LIKE %s", "%{$search_query}%", "%{$search_query}%"));
        $total_pages = ceil($total_products / $products_per_page);

        if ($total_pages > 1) {

		echo '<center><div class="tablenav-pages">';
		echo paginate_links(array(
			'base' => esc_url( add_query_arg('paged', '%#%') ),  // Escape URL properly
			'format' => '',
			'prev_text' => esc_html__('&laquo;', 'quickaffilink'),  // Use esc_html__ for translating text
			'next_text' => esc_html__('&raquo;', 'quickaffilink'),  // Use esc_html__ for translating text
			'total' => absint( $total_pages ),  // Ensure total pages is an integer
			'current' => absint( $current_page ) // Ensure current page is an integer
		));
		echo '</div></center>';

        }
        ?>
    </div>

<div id="quickaffilink-myModal" class="quickaffilink-modal">
  <div class="quickaffilink-modal-content">
    <span class="quickaffilink-close">&times;</span>
	<div id="quickaffilink-modal-message"><img src="<?php echo esc_url( plugin_dir_url( __FILE__ ) . 'assets/images/loader.gif' ); ?>" height="30" alt="<?php echo esc_attr( 'Loading' ); ?>"></div>
  </div>
</div>









	<?php
}

// Register custom admin actions for deleting products
add_action('admin_post_delete_product', 'quickaffilink_delete_product_callback');
add_action('admin_post_nopriv_delete_product', 'quickaffilink_delete_product_callback');

/**
 * Callback function to delete a product.
 */
function quickaffilink_delete_product_callback() {
    // Check user capability to manage options (admins)
    if (!current_user_can('manage_options')) {
        wp_die('You are not allowed to delete products.');
    }

	$security_nonce = isset($_POST['security']) ? sanitize_text_field(wp_unslash($_POST['security'])) : ''; // Sanitize early
	
	if (!$security_nonce || !wp_verify_nonce($security_nonce, 'quickaffilink_delete_product_nonce')) { 	// Validate
		wp_die(esc_html__('Nonce verification failed.', 'quickaffilink'));
	}

    // Get product ID from the request parameters
    $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
    if ($product_id <= 0) {
        wp_die('Invalid product ID.');
    }

    // Global WordPress database object
    global $wpdb;
    
    // Table name for products
    $table_name = $wpdb->prefix . 'quickaffilink_products';
    
    // Delete the product from the database
    $result = $wpdb->delete($table_name, array('id' => $product_id), array('%d'));
    
    // Check if deletion was successful
    if ($result === false) {
        wp_die('Error occurred while deleting product: ' . $wpdb->last_error);
    }

    // Redirect to the product list page in the admin panel
    wp_redirect(admin_url('admin.php?page=quickaffilink-list-products'));
    exit;
}



##########################################################################
####### HANDLING THE STYLES AND JS
##########################################################################
/**
 * Enqueue styles and scripts for the admin dashboard.
 *
 * This function enqueues the necessary styles and scripts for the admin dashboard
 * to enhance the user experience and functionality.
 */

function quickaffilink_enqueue_admin_scripts_and_styles() {
  // Enqueue admin styles
  wp_enqueue_style('quickaffilink-admin-styles', plugins_url('assets/css/admin-style.css', __FILE__));
  wp_enqueue_style('quickaffilink-web-styles', plugins_url('assets/css/quickaffilink-product-style.css', __FILE__));

  // Enqueue admin scripts
  wp_enqueue_script('quickaffilink-admin-scripts', plugins_url('assets/js/admin.js', __FILE__), array('jquery'), '1.0', true);

  // Generate a time-based security token (replace with your actual function)
  $security_nonce = wp_create_nonce('quickaffilink_security_nonce');

  // Localize the admin script to make the security nonce available
  wp_localize_script('quickaffilink-admin-scripts', 'ajax_object', array(
    'ajax_nonce' => $security_nonce
  ));
	
}
// Hook the function to the admin_enqueue_scripts action hook
add_action('admin_enqueue_scripts', 'quickaffilink_enqueue_admin_scripts_and_styles');

/**
 * Enqueues CSS and JS for the front end.
 *
 * This function enqueues the CSS file 'quickaffilink-product-style.css' and JS file 'quickaffilink.js'
 * for use on the front end.
 */
// Enqueue scripts and styles

function quickaffilink_enqueue_scripts() {
    // Enqueue the CSS file for the front end
    wp_enqueue_style('quickaffilink-product-style', plugin_dir_url(__FILE__) . 'assets/css/quickaffilink-product-style.css');

    // Enqueue the JS file for the front end
    wp_enqueue_script('quickaffilink-script', plugin_dir_url(__FILE__) . 'assets/js/quickaffilink.js', array('jquery'), null, true);

    // Get REST API endpoint URL
    $rest_url = rest_url('quickaffilink/v1/record_click');
    $security_nonce =   quickaffilink_generate_time_based_token();
	
    // Localize the script to make REST API endpoint URL and security nonce available
    wp_localize_script('quickaffilink-script', 'QalAjax', array(
        'rest_url' => $rest_url,
        'security' => $security_nonce
    ));
}
add_action('wp_enqueue_scripts', 'quickaffilink_enqueue_scripts');

// Callback function to handle record shortcode and click information
function quickaffilink_record_shortcode_and_click_info( $request ) {
    // Get nonce from the HTTP header
    $security_nonce = $request->get_header('X-WP-QAL');
	$is_secure = 0;
	$is_secure_ref = 0;
	
	if(quickaffilink_verify_referral()){
		$is_secure_ref = 1;
	}

	if(quickaffilink_verify_time_based_token($security_nonce)){
		$is_secure = 1;
	}

    if (($security_nonce == "") && (!quickaffilink_verify_referral())) {
        return new WP_Error( 'invalid_nonce', 'Invalid security nonce.', array( 'status' => 403 ) );
    }
  

	// Get the shortcode usage ID and product ID from the request data
	$shortcode_usage_id = isset($request['shortcode_usage_id']) ? intval(sanitize_text_field(wp_unslash($request['shortcode_usage_id']))) : 0;
	$product_id = isset($request['product_id']) ? intval(sanitize_text_field(wp_unslash($request['product_id']))) : 0;

	// Perform additional data validation if needed
    if ($shortcode_usage_id <= 0 || $product_id <= 0) {
        return new WP_Error( 'invalid_data', 'Invalid data.', array( 'status' => 400 ) );
    }

    // Insert the record into the database
    global $wpdb;
    $clicked_info_table_name = $wpdb->prefix . 'quickaffilink_sc_prod_stats';
    $wpdb->insert(
        $clicked_info_table_name,
        array(
            'shortcode_usage_id' => $shortcode_usage_id,
            'product_id' => $product_id,
            'clicked_at' => current_time('mysql')
        ),
        array(
            '%d', // 'shortcode_usage_id' is an integer
            '%d', // 'product_id' is an integer
            '%s'  // 'clicked_at' is a timestamp
        )
    );

    // Check if the insertion was successful
    if ($wpdb->last_error) {
        // Can open this for debugging but not by default
        // return new WP_Error( 'db_error', 'Database error.', array( 'status' => 500 ) );
    }

    // Return success response
    return new WP_REST_Response( 'Success.', 200 );
}

add_action('rest_api_init', 'quickaffilink_custom_endpoint');

function quickaffilink_custom_endpoint() {
    register_rest_route('quickaffilink/v1', '/record_click', array(
        'methods' => 'POST',
        'callback' => 'quickaffilink_record_shortcode_and_click_info',
        'permission_callback' => '__return_true', // Allow anonymous access
    ));
}
