<?php
if(!defined('ABSPATH')){
	die('Hacking Attempt!');
}
/**
 * Renders the dashboard page for the QuickAffiLink plugin.
 */
function quickaffilink_render_dashboard() {
    global $wpdb;
    $current_user = wp_get_current_user();
    $user_name = $current_user->display_name;
  
	// Fetch data from the database
	 $top_categories_data = $wpdb->get_results(
		"SELECT category, COUNT(*) AS count
		FROM {$wpdb->prefix}quickaffilink_products
		WHERE category IS NOT NULL AND category != ''
		GROUP BY category
		ORDER BY count DESC
		LIMIT 5",
		ARRAY_A
	);
	$most_clicked_products = $wpdb->get_results(
		"SELECT p.title, COUNT(ps.id) AS num_ratings
		FROM {$wpdb->prefix}quickaffilink_products AS p
		INNER JOIN {$wpdb->prefix}quickaffilink_sc_prod_stats AS ps ON p.id = ps.product_id
		GROUP BY p.title
		ORDER BY num_ratings DESC
		LIMIT 5",
		ARRAY_A
	);


	$top_pages_with_shortcodes = $wpdb->get_results("SELECT url, COUNT(DISTINCT shortcode_name) AS shortcode_count FROM {$wpdb->prefix}quickaffilink_sc_stats WHERE url NOT LIKE '%wp-admin%' AND url NOT LIKE '%wp-json%' GROUP BY url ORDER BY shortcode_count DESC LIMIT 5", ARRAY_A);
    $top_shortcodes_with_pages = $wpdb->get_results("SELECT shortcode_name, COUNT(*) AS page_count FROM {$wpdb->prefix}quickaffilink_sc_stats where url NOT LIKE '%wp-admin%' AND url NOT LIKE '%wp-json%' GROUP BY shortcode_name ORDER BY page_count DESC LIMIT 5", ARRAY_A);
    $latest_products = $wpdb->get_results("SELECT title, last_saved FROM {$wpdb->prefix}quickaffilink_products ORDER BY last_saved DESC LIMIT 5", ARRAY_A);
    $recent_shortcodes_displayed = $wpdb->get_results("SELECT shortcode_name, COUNT(*) AS display_count FROM {$wpdb->prefix}quickaffilink_sc_stats GROUP BY shortcode_name ORDER BY last_seen DESC LIMIT 5", ARRAY_A);

	$current_domain = "http" . (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "s" : "") . "://" . (isset($_SERVER['HTTP_HOST']) ? sanitize_text_field(wp_unslash($_SERVER['HTTP_HOST'])) : '');
// Output the dashboard page content
    ?>
    <div class="wrap">
        <h1>Dashboard</h1>
		<h2>Welcome to Your QuickAffilink Dashboard, <?php echo esc_html( $user_name ); ?>!</h2>
		<p>Explore key metrics and insights related to your affiliate marketing activities. From top product categories to recent shortcode displays, gain valuable information to optimize your campaigns and track performance.</p>

          <?php if (empty($latest_products)) { ?>
	 <h3 style="color:red;">It seems there are no products added. If you have just installed the plugin, please follow the steps mentioned <a href="admin.php?page=quickaffilink-about#getting_started">here</a> to get started.<h3>
		  <?php } ?>
 		<h2>Statistics and Insights</h2> 
		<div class="container">	
			<div class="row">
                <div class="col-md-4">

                    <!-- Top Product Categories -->
                    <div class="qaf-dashboard postbox">				
                        <div class="postbox-header"><h2 class="hndle">Top Product Categories</h2></div>
                        <div class="inside">
                            <?php if (!empty($top_categories_data)) : ?>
                                <ul>
                                    <?php foreach ($top_categories_data as $category) : ?>
									<li><span title="<?php echo esc_html(stripslashes($category['category'])); ?>"><?php echo esc_html(stripslashes($category['category'])); ?></span><?php echo esc_html($category['count']); ?> products</li>
									<?php endforeach; ?>
                                </ul>
                            <?php else : ?>
                                <p class="no-data" title="Data not available">Data not available</p>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <div class="col-md-4">
                    <!-- Most Clicked Products -->
                    <div class="qaf-dashboard postbox">
                        <div class="postbox-header"><h2 class="hndle">Most Clicked Products</h2></div>
                        <div class="inside">
                            <?php if (!empty($most_clicked_products)) : ?>
								<ul>
								<?php foreach ($most_clicked_products as $product) : ?>
									<li><span title="<?php echo esc_html( stripslashes( $product['title'] ) ); ?>"><?php echo esc_html( quickaffilink_trim_title( stripslashes( $product['title'] ), 2 ) ); ?></span>
										<?php echo esc_html( $product['num_ratings'] ); ?> clicks</li>
								<?php endforeach; ?>
                                </ul>
                            <?php else : ?>
                                <p class="no-data" title="Data not available">Data not available</p>
                            <?php endif; ?>
                        </div></div>    </div>
                <div class="col-md-4">
                    <!-- Top Pages with Shortcodes -->
                    <div class="qaf-dashboard postbox">
                        <div class="postbox-header"><h2 class="hndle">Top Pages with Shortcodes</h2></div>
                        <div class="inside">
                            <?php if (!empty($top_pages_with_shortcodes)) : ?>
                                <ul>
                                    <?php foreach ($top_pages_with_shortcodes as $page) : ?>
										<li><a href="<?php echo esc_url( $current_domain . $page['url'] ); ?>" title="<?php echo esc_attr( $current_domain . $page['url'] ); ?>" target="_blank">Clickable URL</a> <?php echo esc_html( $page['shortcode_count'] ); ?> shortcodes</li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php else : ?>
                                <p class="no-data" title="Data not available">Data not available</p>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-md-4">
                    <!-- Top Shortcodes with Pages -->
                    <div class="qaf-dashboard postbox">
                        <div class="postbox-header"><h2 class="hndle">Top Shortcodes with Pages</h2></div>
                        <div class="inside">
                            <?php if (!empty($top_shortcodes_with_pages)) : ?>
                                <ul>
                                    <?php foreach ($top_shortcodes_with_pages as $shortcode) : ?>
										<li><span title="<?php echo esc_attr( quickaffilink_fullShortcodeName( $shortcode['shortcode_name'] ) ); ?>"><?php echo esc_html( quickaffilink_fullShortcodeName( $shortcode['shortcode_name'] ) ); ?></span> <?php echo esc_html( $shortcode['page_count'] ); ?> pages</li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php else : ?>
                                <p class="no-data" title="Data not available">Data not available</p>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <div class="col-md-4">
                    <!-- Latest Products -->
                    <div class="qaf-dashboard postbox">
                        <div class="postbox-header"><h2 class="hndle">Latest Products</h2></div>
                        <div class="inside">
                            <?php if (!empty($latest_products)) : ?>
                                <ul>
                                    <?php foreach ($latest_products as $product) : ?>
										<li><span title="<?php echo esc_attr( stripslashes( $product['title'] ) ); ?>"><?php echo esc_html( quickaffilink_trim_title( stripslashes( $product['title'] ), 2 ) ); ?></span> <?php echo esc_html( gmdate( 'M j, Y', strtotime( $product['last_saved'] ) ) ); ?></li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php else : ?>
                                <p class="no-data" title="Data not available">Data not available</p>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <div class="col-md-4">
                    <!-- Recent Shortcodes Displayed -->
                    <div class="qaf-dashboard postbox">
                        <div class="postbox-header"><h2 class="hndle">Recent Shortcodes Displayed</h2></div>
                        <div class="inside">
                            <?php if (!empty($recent_shortcodes_displayed)) : ?>
                                <ul>
                                    <?php foreach ($recent_shortcodes_displayed as $shortcode) : ?>
										<li><span title="<?php echo esc_attr( quickaffilink_fullShortcodeName( $shortcode['shortcode_name'] ) ); ?>"><?php echo esc_html( quickaffilink_fullShortcodeName( $shortcode['shortcode_name'] ) ); ?></span> <?php echo esc_html( $shortcode['display_count'] ); ?> times</li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php else : ?>
                                <p class="no-data" title="Data not available">Data not available</p>
                            <?php endif; ?>
                        </div>
                    </div>
            </div>
        </div>
   

    
<?php



}
