<?php

function quickaffilink_display_cat_store_select() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'quickaffilink_products';

    // Fetch categories with at least 2 products
    $categories = $wpdb->get_results("
        SELECT category, COUNT(*) AS total_products
        FROM $table_name
        GROUP BY category
        HAVING total_products >= 2
        ORDER BY category
        LIMIT 5
    ");

    // Fetch unique store URLs related to the selected categories
    $store_urls = $wpdb->get_col("
        SELECT DISTINCT store_url
        FROM $table_name
        WHERE category IN (
            SELECT category
            FROM $table_name
            GROUP BY category
            HAVING COUNT(*) >= 2
        )
    ");

    // Get submitted values
	$selected_category = isset($_POST['category']) ? sanitize_text_field(wp_unslash($_POST['category'])) : '';
	$selected_store = isset($_POST['store_url']) ? esc_url_raw(sanitize_text_field(wp_unslash($_POST['store_url']))) : '';

    // Start select box HTML
    ?>
    <form id="category_store_form" method="post" action="admin.php?page=quickaffilink-sample-usage">
        <?php echo esc_html($selected_store); ?><select name="category">
            <option value="">Please select a category</option>
            <?php
            // Loop through categories and display options
            foreach ($categories as $category) {
                $selected = ($selected_category == $category->category) ? 'selected' : '';
				echo '<option value="' . esc_attr( $category->category ) . '" ' . esc_attr( $selected ) . '>' . esc_html( $category->category ) . '</option>';
            }
            ?>
        </select>
        <select name="store_url">
            <option value="">Please select a store URL</option>
            <?php
            // Loop through store URLs and display options
            foreach ($store_urls as $url) {
                $selected = ($selected_store == esc_url( $url )) ? 'selected' : '';
		          echo '<option value="' . esc_url( $url ) . '" ' . esc_attr( $selected ) . '>' . esc_html( $url ) . '</option>';
            }
            ?>
        </select>
        <input type="hidden" name="operation" value="multiple">
        <input type="submit" value="Display Shortcodes">
    </form>
    <?php
}


function quickaffilink_display_product_select_box() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'quickaffilink_products';

    // Check if form is submitted and product_id is set
    if (isset($_POST['product_id'])) {
        // Ensure product_id is not empty and is a valid integer
        if (!empty($_POST['product_id']) && is_numeric($_POST['product_id'])) {
            $product_id = intval($_POST['product_id']);

            // Validate product_id against the database
            $result = $wpdb->get_row($wpdb->prepare("SELECT id, title FROM $table_name WHERE id = %d", $product_id));

            // If product_id is valid, perform actions
            if ($result) {
                // Handle the product ID as needed
                //echo "Product ID: $product_id";
                // Redirect to another page if necessary
                //wp_safe_redirect(admin_url('admin.php?page=quickaffilink-sample-usage'));
                //exit;
            } else {
                // Invalid product_id, display an error message
                echo '<p style="color: red;">Invalid product selection!</p>';
                exit;
            }
        } else {
            // Invalid product_id format, display an error message
            echo '<p style="color: red;">Invalid product ID format!</p>';
            exit;
        }
    }

    // Fetch the top five product titles by ID
    $results = $wpdb->get_results("SELECT id, title FROM $table_name ORDER BY id desc LIMIT 5");

    // Start select box HTML
    ?>
    <form id="product_sample_form" method="post" action="admin.php?page=quickaffilink-sample-usage">
        <select name="product_id">
            <option value="">Please select a product to preview samples</option>
            <?php
            // Loop through results and display options
            foreach ($results as $product) {
                // Check if the current product id matches the posted product_id
                $selected = isset($_POST['product_id']) && $_POST['product_id'] == $product->id ? 'selected' : '';
           echo '<option value="' . esc_attr( $product->id ) . '" ' . esc_attr( $selected ) . '>' . esc_html( stripslashes( quickaffilink_trim_title( $product->title ) ) ) . '</option>';
            }
            ?>
        </select>
        <input type="submit" value="Display Shortcodes">
    </form>

    <?php
}




// Function to render Sample Usage page content

function quickaffilink_render_sample_usage_page() {
    ?>
    <div class="wrap">
        <h1>Sample Usage of Short Codes(with your products data)</h1>
	<p>Note: This screen provides visual guidance for using shortcodes by offering a preview using your own added product data. To utilize this functionality, you must first add some products using the <a href="admin.php?page=quickaffilink-add-product">Add Product</a> screen.</p>
		<h1>Single Products</h1>


 
<?php

echo esc_html( quickaffilink_display_product_select_box() );

if (!empty($_POST['product_id']) && is_numeric($_POST['product_id'])) {
    $product_id = intval($_POST['product_id']);
	// Fetch product data by ID
	//$product_id = 2; // Example product ID
	$product = quickaffilink_get_product_data($product_id);
    $prepared_affiliate_link = quickaffilink_append_affiliate_tag_to_url($product->store_url, $product->product_url);
	$learnmore = "false";
	
?>
<br /><br />

<h2>Small (Dimensions: 300x250px)</h2>
<p>The short code for using this style is <code class="codeBlock">[quickaffilink id="<?php echo esc_attr( $product->id ); ?>" size="small"]</code></p>

<?php 	
require_once plugin_dir_path( __FILE__ ) . 'templates/inc_sml_var1.php';	
?>

<h2>Medium (Dimensions: 480x320px - Variant 1)</h2>
<p>The short code for using this style is <code class="codeBlock">[quickaffilink id="<?php echo esc_attr( $product->id ); ?>" size="medium" var="1"]</code></p>
<?php 	
require_once plugin_dir_path( __FILE__ ) . 'templates/inc_med_var1.php';	
?>

<h2>Medium (Dimensions: 480x320px - Variant 2)</h2>
<p>The short code for using this style is <code class="codeBlock">[quickaffilink id="<?php echo esc_attr( $product->id ); ?>" size="medium" var="2"]</code></p>

<?php 	
require_once plugin_dir_path( __FILE__ ) . 'templates/inc_med_var2.php';	
?>

<h2>Large (Dimensions: 1200x628px - Variant 1)</h2>
<p>The short code for using this style is <code class="codeBlock">[quickaffilink id="<?php echo esc_attr( $product->id ); ?>" size="large"]</code></p>
<?php 	
require_once plugin_dir_path( __FILE__ ) . 'templates/inc_lar_var1.php';	
?>

<?php
	} // end product id


?>

<hr />
<h1> Multiple Products </h1>
<p>In order for this to sample to work, please add multiple products from the same Amazon category on your website</p>

<?php
	quickaffilink_display_cat_store_select();	
?>



<?php

if(isset($_POST['operation']) && ($_POST['operation'] == "multiple") ){


if (isset($_POST['store_url']) && wp_unslash($_POST['store_url']) == "") {

	echo "<font color=\"red\">Store URL not provided! </font> <br />";
}
if (isset($_POST['category']) && wp_unslash($_POST['category']) == "") {
	echo "<font color=\"red\">Category not provided! </font> <br />";
}

if (isset($_POST['category']) && wp_unslash($_POST['category']) != "" && isset($_POST['store_url']) && wp_unslash($_POST['store_url']) != "") {

?>
<h2>Multiple Products - Group</h2>

<?php
    global $wpdb;
	$learnmore = "false";
    $table_name_p = $wpdb->prefix . 'quickaffilink_products';
	$store_url = isset($_POST['store_url']) ? sanitize_text_field(wp_unslash($_POST['store_url'])) : '';
	$category = isset($_POST['category']) ? sanitize_text_field(wp_unslash($_POST['category'])) : '';

    $store_url = str_replace(array('http://', 'https://'), '', $store_url); // Remove protocols

	// Prepare the query with placeholders
     $query_results = $wpdb->get_results( $wpdb->prepare("SELECT * FROM $table_name_p WHERE store_url = %s AND category = %s ORDER BY last_saved DESC LIMIT 5", $store_url, $category));
	
	// Initialize an empty array to store IDs
	$ids = array();
	// Iterate through the results and extract IDs
	foreach ($query_results as $result) {
		$ids[] = $result->id;
	}
	// Join the IDs with a comma separator
	$commaSeparatedIds = implode(',', $ids);
?>
<p>The short code for using this style is <code class="codeBlock">[quickaffilink multiple="true" category="<?php echo esc_attr( $category ); ?>" store="<?php echo esc_html( $store_url ); ?>" ]</code> and it will bring the latest fetched top 5 products from the specified category</p>

<p>Other Variant could be <code class="codeBlock">[quickaffilink multiple="true" ids="<?php echo esc_attr( $commaSeparatedIds ); ?>" ]</code> In this case, you don't have to limit yourself to one category or one store; you can specify IDs from any category or store (use it wisely). This will ignore any additional IDs beyond 5 if specified.</p>
<?php
	// Execute the prepared query
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name_p WHERE store_url = %s AND category = %s ORDER BY last_saved DESC LIMIT 5", $store_url, $category));
	require_once plugin_dir_path( __FILE__ ) . 'templates/inc_grp_var1.php';	
}

}// end condition.
?>
<h1>More Usage Examples</h1>
<p>Customize the displayed product by adding optional attributes to the shortcode, such as [quickaffilink category="Beauty" multiple="true"], [quickaffilink ids="1,2,3" multiple="true"], [quickaffilink id="123" size="small"], [quickaffilink id="123" size="medium"], [quickaffilink id="123" size="large"], or [quickaffilink asin="product_asin" size="small"] etc </p>

<!-- Page end Div -->
</div>
<?php


} // end main page function