<?php
if(!defined('ABSPATH')){
	die('Hacking Attempt!');
}

/**
 * Shortcode handler for displaying product information.
 *
 * This function serves as the handler for the 'quickaffilink' shortcode. It accepts various attributes to fetch product details
 * from the database based on the provided attributes such as 'id' or 'asin'. It then generates HTML output to display
 * the product image, title, price, rating, and a link to purchase the product.
 *
 * @param array $atts An array of attributes passed with the shortcode.
 * @return string HTML output to display the product information.
 */
function quickaffilink_shortcode_handler($atts) {
    // Extract shortcode attributes with default values
    $atts = shortcode_atts(array(
        'id' => '',         // Default value for id attribute
        'multiple' => 'false',    // Default value for multiple attribute
        'asin' => '',       // Default value for asin attribute
        'var' => '1',       // Default value for variant attribute
        'ids' => '',       // Default value for variant attribute        
		'category' => '',       // Default value for category attribute
        'learnmore' => 'false',       // Default value for learnmore attribute		
		'size' => 'small', // Default value for size attribute
		'store' => '', // Default value for store attribute
	), $atts, 'quickaffilink');




	$id = isset($atts['id']) ? intval($atts['id']) : 0; // Convert to integer or default to 0 if not an integer
    $multiple = $atts['multiple'];
    $asin = $atts['asin'];
	
	$allowed_var_values = [1, 2, 3];
	$var = isset($atts['var']) && in_array($atts['var'], $allowed_var_values) ? intval($atts['var']) : '1';
	
	$ids = $atts['ids'];
    $category = $atts['category'];
    $learnmore = $atts['learnmore'];
	
	$allowed_size_values = ['small', 'medium', 'large', 'full-screen'];
	$size = isset($atts['size']) && in_array($atts['size'], $allowed_size_values) ? $atts['size'] : 'small'; // Check if the size is in the predefined array, otherwise use a default value
	$store = $atts['store'];


    // Get product details based on provided attributes
    global $wpdb;
    $table_name = $wpdb->prefix . 'quickaffilink_products';
    $product = null;


	// Now the logic, first determining if it is a single or multiple 
	if ($multiple == "true") {
		  // Check if the user provided IDs
		if (!empty($ids) && empty($category)) {
			// Split the string into an array of integers
			$ids_array = preg_split("/\s*,\s*/", $ids);

			// Filter out non-integer values
			$ids_array = array_filter($ids_array, 'is_numeric');
			$ids_array = array_map('intval', $ids_array);

			// Take only the first five integers
			$ids_array = array_slice($ids_array, 0, 5);

			// Construct the list of placeholders for the prepared statement
			$placeholders = array_fill(0, count($ids_array), '%d');

			// Create the placeholder string by joining the placeholders with commas
			$placeholders_string = implode(', ', $placeholders);

			// Prepare an array of arguments for wpdb::prepare()
			$prepare_args = $ids_array;

			// Construct the SQL query with dynamically generated OR conditions
			$pp1 = $wpdb->prepare("SELECT * FROM $table_name WHERE id IN ($placeholders_string) ORDER BY last_saved DESC LIMIT 5", $prepare_args);

		
		} elseif (!empty($category) && !empty($store)) {
			// Sanitize inputs
			$sanitized_store = sanitize_text_field($store);
			$sanitized_category = sanitize_text_field($category);

			// Prepare SQL query with placeholders
			$pp1 = $wpdb->prepare("SELECT * FROM $table_name WHERE store_url = %s AND category = %s ORDER BY last_saved DESC LIMIT 5", $sanitized_store, $sanitized_category);
		}

		$results = $wpdb->get_results($pp1);
		// Require template file
		$id_results = $wpdb->get_col($pp1);
		$product_ids_csv = implode(',', $id_results);
		
		$unique_sc_id = quickaffilink_record_shortcode_usage('grp_var1');
		
		ob_start();
		echo "<div class=\"qal-sccls-" . esc_attr( $unique_sc_id ) . "\">";
			include plugin_dir_path(__FILE__) . 'templates/inc_grp_var1.php';
		echo "</div>";
		$inner_data = ob_get_clean();
		return $inner_data;
	}
	else{ // not multiple but single, all related logic will come here
	

    // Determine which attribute to use for fetching product details
    if (!empty($id)) {
        // Use 'id' attribute if provided
        $product_id = intval($id);
        $product = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE id = %d", $product_id));
    } elseif (!empty( $asin)) {
        // Use 'asin' attribute if provided
        $product_asin = sanitize_text_field($asin);
        $product = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE asin = %s", $product_asin));
    }

    // Check if product exists
    if (!$product) {
        return ''; // If product does not exist, return empty string
    }

    // Append affiliate tag to the product URL
    $prepared_affiliate_link = quickaffilink_append_affiliate_tag_to_url($product->store_url, $product->product_url);
			

	ob_start();

	switch ($size . '_' . $var) {
		case 'small_1':
				$unique_sc_id = quickaffilink_record_shortcode_usage('sml_var1');
			echo "<div class=\"qal-sccls-" . esc_attr( $unique_sc_id ) . "\">";
					include plugin_dir_path( __FILE__ ) . 'templates/inc_sml_var1.php';	
				echo "</div>";
			break;
		case 'medium_1':
				$unique_sc_id = quickaffilink_record_shortcode_usage('med_var1');
			echo "<div class=\"qal-sccls-" . esc_attr( $unique_sc_id ) . "\">";	
					include plugin_dir_path( __FILE__ ) . 'templates/inc_med_var1.php';	
				echo "</div>";			
			break;
		case 'medium_2':
				$unique_sc_id = quickaffilink_record_shortcode_usage('med_var2');
			echo "<div class=\"qal-sccls-" . esc_attr( $unique_sc_id ) . "\">";
					include plugin_dir_path( __FILE__ ) . 'templates/inc_med_var2.php';	
				echo "</div>";
			break;
		case 'medium_3':
			break;
		case 'large_1':
				$unique_sc_id = quickaffilink_record_shortcode_usage('lar_var1');
		echo "<div class=\"qal-sccls-" . esc_attr( $unique_sc_id ) . "\">";
					include plugin_dir_path( __FILE__ ) . 'templates/inc_lar_var1.php';	
				echo "</div>";
			break;
		default:
				$unique_sc_id = quickaffilink_record_shortcode_usage('sml_var1');
		echo "<div class=\"qal-sccls-" . esc_attr( $unique_sc_id ) . "\">";
					include plugin_dir_path( __FILE__ ) . 'templates/inc_sml_var1.php';	
				echo "</div>";
	}
	
	$inner_data = ob_get_clean();
	return $inner_data;

	}// end single
   
}

// Register the shortcode handler
add_shortcode('quickaffilink', 'quickaffilink_shortcode_handler');
